@@ -14,37 +14,30 @@ use Interchange6::Schema::Candy;
 
 =head2 product_attribute_values_id
 
-  data_type: 'integer'
-  is_auto_increment: 1
-  is_nullable: 0
-  primary key
+Primary key.
 
 =cut
 
 primary_column product_attribute_values_id =>
-  { data_type => "integer", is_auto_increment => 1, is_nullable => 0, };
+  { data_type => "integer", is_auto_increment => 1 };
 
 =head2 product_attributes_id
 
-  data_type: 'integer'
-  is_foreign_key: 1
-  is_nullable: 0
+FK on L<Interchange6::Schema::Result::ProductAttribute/product_attributes_id>.
 
 =cut
 
 column product_attributes_id =>
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 };
+  { data_type => "integer", is_foreign_key => 1 };
 
 =head2 attribute_values_id
 
-  data_type: 'integer'
-  is_foreign_key: 1
-  is_nullable: 0
+FK on L<Interchange6::Schema::Result::AttributeValue/attribute_values_id>.
 
 =cut
 
 column attribute_values_id =>
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 };
+  { data_type => "integer", is_foreign_key => 1 };
 
 =head1 RELATIONS
 
